/*
Copyright (C) 2024 Christoph Boelitz

E-mail: tools@dosforum.de
Project page: http://tools.dosforum.de/

This program is free software as long as its used privately.
Commercial use, as unlikely as it may seem, is hereby prohibited.
The source code may be modified and distributed as long
as my contact information is left in place.

Let me know, if you have suggestions or see something that can
be done in a better way, so I might learn from it. Thanks!
*/

#ifndef _CONFIG_H_INCLUDED
#define _CONFIG_H_INCLUDED

// Configuration for common module
// ----------------------------------------------------------------------------

// If COMMON_BANNER_NAME is not set, banner will not be used/shown!
#define COMMON_BANNER_VER     "1.3.0"
#define COMMON_BANNER_NAME    "CDBeQuiet!"
#define COMMON_BANNER_AUTHOR  "ChrisR3tro"
#define COMMON_BANNER_EMAIL   "tools@dosforum.de"
#define COMMON_BANNER_URL     "http://tools.dosforum.de/"

#define COMMON_SHOW_BANNER_ON_STARTUP

#define COMMON_USAGE_TEXT \
  "Usage: cdbq /P port /D device /S speed [/F] [/Q]\n" \
  "       cdbq /P port /D device /I\n" \
  "       cdbq /P port /D device /R [/Q]\n" \
  "\n" \
  "Command-line options:\n\n" \
  "  /P port    Specify IDE port. (1 = primary, 2 = secondary, 3, 4)\n" \
  "  /D device  Specify device mode. (m = master, s = slave)\n" \
  "  /S speed   Set custom CD read speed in kb/s (0 for reset/max).\n" \
  "  /I         Just print out device information and exit.\n" \
  "  /R         Perform soft-reset of drive and exit (experimental).\n" \
  "  /F         Force skipping of some sanity checks.\n" \
  "  /Q         Suppress text output.\n" \
  "  /?         This help screen :)\n" \
  "\n" \
  "Example:\n" \
  "  If you wanted to set a CD speed of 4x (1x = 150 kb/s) for a drive,\n" \
  "  which acts as master on your 2nd IDE port, this is how it should look:\n" \
  "    cdbq /P2 /Dm /S600"


// App-specific configuration
// ----------------------------------------------------------------------------

// According to spec, 0xFFFFh is equivalent to max speed.
#define CDBQ_CFG_MAX_SPEED_SETTING    0xFFFEu

#endif



