/*
Copyright (C) 2024 Christoph Boelitz

E-mail: tools@dosforum.de
Project page: http://tools.dosforum.de/

This program is free software as long as its used privately.
Commercial use, as unlikely as it may seem, is hereby prohibited.
The source code may be modified and distributed as long
as my contact information is left in place.

Let me know, if you have suggestions or see something that can
be done in a better way, so I might learn from it. Thanks!
*/

// Includes
#include <string.h>
#include <ctype.h>

#include "str.h"

bool is_null_or_empty(const char* str)
{
	return str == NULL || str[0] == '\0';
}

char to_lower(char c)
{
  if ((int)c > (int)'Z' || (int)c < (int)'A')
    return c;

  return (char)((int)c + ((int)'a' - (int)'A'));
}


int find_char_in_str_stop_at(char c, const char* str, char stop_chr)
{
	int i = 0;

	while (str[i] != stop_chr)
	{
		if (str[i++] == c)
			return i;
	}

	return -1;
}

int find_char_in_str(char c, const char* str)
{
	return find_char_in_str_stop_at(c, str, '\0');
}

const char* ltrim(const char *str)
{
  while (str[0] == ' ')
    str++;

  return str;
}

// Trims a string in memory
// Returns new pointer to the same string
char* trim(char *str)
{
  int len;
	int i;

	len = strlen(str);

  // First, trim leading spaces

  while (str[0] == ' ')
    str++;

  // Trim trailing spaces

  i = len-1;

  while (str[i] == ' ')
    i--;

  str[i+1] = '\0';

  return str;
}
