/*
Copyright (C) 2024 Christoph Boelitz

E-mail: tools@dosforum.de
Project page: http://tools.dosforum.de/

This program is free software as long as its used privately.
Commercial use, as unlikely as it may seem, is hereby prohibited.
The source code may be modified and distributed as long
as my contact information is left in place.

Let me know, if you have suggestions or see something that can
be done in a better way, so I might learn from it. Thanks!
*/

// Module for calling BIOS interrupts
// (This is still very preliminary...)

#ifndef _BIOSINT_H_INCLUDED
#define _BIOSINT_H_INCLUDED

// Includes
#include <i86.h>

// BIOS interrupt services

#define BIOSINT_10h_VIDEO                      0x10
#define BIOSINT_10h_00h_SET_MODE               0x00

#define BIOSINT_10h_00h_AL_40x25_TEXT_MONO     0x0
#define BIOSINT_10h_00h_AL_40x25_TEXT_COLOR    0x1
#define BIOSINT_10h_00h_AL_80x25_TEXT_MONO     0x2
#define BIOSINT_10h_00h_AL_80x25_TEXT_COLOR    0x3
#define BIOSINT_10h_00h_AL_320x200_4COLOR      0x4
#define BIOSINT_10h_00h_AL_320x200_4COLOR_MONO 0x5 // Colors are in mono
#define BIOSINT_10h_00h_AL_640x200_2COLOR      0x6
#define BIOSINT_10h_00h_AL_INTERNAL_MONO       0x7

#define BIOSINT_10h_02h_SET_CURSOR_POS         0x02

#define BIOSINT_10h_03h_GET_CURSOR_POS         0x03

#define BIOSINT_10h_09h_WRITE_CHAR             0x09

// Attribute bit
// Bit 76543210
//     ||||||||
//     |||||^^^-fore colour
//     ||||^----fore colour bright bit
//     |^^^-----back colour
//     ^--------back colour bright bit OR enables blinking Text


#define BIOSINT_10h_CHATTR_FCOL_BLACK          0x00 // #000000
#define BIOSINT_10h_CHATTR_FCOL_BLUE           0x01 // #0000AA
#define BIOSINT_10h_CHATTR_FCOL_GREEN          0x02 // #00AA00
#define BIOSINT_10h_CHATTR_FCOL_CYAN           0x03 // #00AAAA
#define BIOSINT_10h_CHATTR_FCOL_RED            0x04 // #AA0000
#define BIOSINT_10h_CHATTR_FCOL_MAGENTA        0x05 // #AA00AA
#define BIOSINT_10h_CHATTR_FCOL_BROWN          0x06 // #AA5500
#define BIOSINT_10h_CHATTR_FCOL_LIGHTGRAY      0x07 // #AAAAAA

// Some bright foreground colors shortcuts
#define BIOSINT_10h_CHATTR_FCOL_DARKGRAY (BIOSINT_10h_CHATTR_FCOL_BLUE \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #555555
#define BIOSINT_10h_CHATTR_FCOL_LIGHTBLUE (BIOSINT_10h_CHATTR_FCOL_BLUE \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #5555FF
#define BIOSINT_10h_CHATTR_FCOL_LIGHTGREEN (BIOSINT_10h_CHATTR_FCOL_GREEN \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #55FF55
#define BIOSINT_10h_CHATTR_FCOL_LIGHTCYAN (BIOSINT_10h_CHATTR_FCOL_CYAN \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #55FFFF
#define BIOSINT_10h_CHATTR_FCOL_LIGHTRED (BIOSINT_10h_CHATTR_FCOL_RED \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #FF5555
#define BIOSINT_10h_CHATTR_FCOL_LIGHTMAGENTA (BIOSINT_10h_CHATTR_FCOL_MAGENTA \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #FF55FF
#define BIOSINT_10h_CHATTR_FCOL_YELLOW (BIOSINT_10h_CHATTR_FCOL_BROWN \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #FFFF55
#define BIOSINT_10h_CHATTR_FCOL_WHITE (BIOSINT_10h_CHATTR_FCOL_LIGHTGRAY \
  | BIOSINT_10h_CHATTR_FCOL_BRIGHT) // #FFFFFF

// Use bitwise-or with this:
#define BIOSINT_10h_CHATTR_FCOL_BRIGHT         0x08

#define BIOSINT_10h_CHATTR_BCOL_BLACK          0x00
#define BIOSINT_10h_CHATTR_BCOL_BLUE           0x10
#define BIOSINT_10h_CHATTR_BCOL_GREEN          0x20
#define BIOSINT_10h_CHATTR_BCOL_CYAN           0x30
#define BIOSINT_10h_CHATTR_BCOL_RED            0x40
#define BIOSINT_10h_CHATTR_BCOL_MAGENTA        0x50
#define BIOSINT_10h_CHATTR_BCOL_YELLOW         0x60
#define BIOSINT_10h_CHATTR_BCOL_GRAY           0x70

// Use bitwise-or with this:
#define BIOSINT_10h_CHATTR_BLINK               0x80








#define BIOSINT_10h_0ah_WRITE_CHAR             0x0a

#define BIOSINT_10h_0eh_WRITE_CHAR             0x0e

#define BIOSINT_10h_0fh_GET_MODE               0x0f



// Prototypes

// Shortcuts
void biosint_sc_video_write_char_attr(unsigned int c_attr);
void biosint_sc_video_adv_cur(int count);


// BIOS services
void biosint_video_set_cursor_pos(unsigned char line, unsigned char col);
void biosint_video_get_cursor_pos(unsigned char *line, unsigned char *col);
void biosint_video_09h_write_char(unsigned char c, unsigned char attr);
void biosint_video_0ah_write_char(unsigned char c);
void biosint_video_0eh_write_char(unsigned char c);
void biosint_video_set_mode(unsigned char mode);
unsigned char biosint_video_get_mode();

#endif
