/*
Copyright (C) 2024 Christoph Boelitz

E-mail: tools@dosforum.de
Project page: http://tools.dosforum.de/

This program is free software as long as its used privately.
Commercial use, as unlikely as it may seem, is hereby prohibited.
The source code may be modified and distributed as long
as my contact information is left in place.

Let me know, if you have suggestions or see something that can
be done in a better way, so I might learn from it. Thanks!
*/

#ifndef _CMDLINE_H_INCLUDED
#define _CMDLINE_H_INCLUDED

// Includes

#include <stdbool.h>

// Include a file that makes basic defines for cmdline module
#include MODCFG_H

//#include "str.h"
#include "errmacro.h"

// Errors (see errmacro.h for explanation!)
#define FOREACH_CMDLINE_ERROR(E) \
E(E_CMDLINE_SUCCESS, "Error handler called on non-error.") \
E(E_CMDLINE_UNEXPECTED_ARG, "Unknown command-line switch. Check usage.") \
E(E_CMDLINE_MISSING_ARG, "Missing command-line switch. Check usage.") \
E(E_CMDLINE_DUPLICATE_ARGS, \
  "Command-line switch found multiple times. Check usage.") \
E(E_CMDLINE_MISSING_OPTION, \
  "Missing option for command-line switch. Check usage.") \
E(E_CMDLINE_UNEXPECTED_OPTION, \
  "Unexpected option for command-line switch. Check usage.") \
E(E_CMDLINE_ARG_CONFLICT, "Conflicting command-line switches. Check usage.") \
E(E_CMDLINE_APP_SPECIFIC, "Command-line parsing error. Check usage.") \
E(E_CMDLINE_APP_UNSPECIFIC, "Unspecific command-line error. Check usage.") \
E(E_CMDLINE_UNKNOWN, \
  "Unknown command-line error. Check usage.") // Has to come last!

#define E_CMDLINE_INIT_SUCCESS    0
#define E_CMDLINE_INIT_USAGESHOWN 1
#define E_CMDLINE_INIT_BAD_ARGS   2

// Defines
typedef enum _cmdline_error { FOREACH_CMDLINE_ERROR(GENERATE_ENUM_MEMBER) }
  cmdline_error_t;

// Types
typedef enum _cmdline_usage_group
{
  CMDLINE_USAGE_GROUP_NONE = 0,
  CMDLINE_USAGE_GROUP_1 = 1,
  CMDLINE_USAGE_GROUP_2 = 2,
  CMDLINE_USAGE_GROUP_3 = 4,
  CMDLINE_USAGE_GROUP_4 = 8,
  CMDLINE_USAGE_GROUP_5 = 16,
  CMDLINE_USAGE_GROUP_6 = 32,
  CMDLINE_USAGE_GROUP_7 = 64,
  CMDLINE_USAGE_GROUP_8 = 128
} cmdline_usage_group_t;

typedef enum _cmdline_arg_flags
{
  CMDLINE_ARG_NONE = 0,
  CMDLINE_ARG_FOUND = 1,
  CMDLINE_ARG_OPTIONAL = 2,
  CMDLINE_ARG_HAS_OPT = 4,
  CMDLINE_ARG_HELP = 8,
  CMDLINE_ARG_QUIET = 16
} cmdline_arg_flags_t;

typedef struct
{
  char arg;
  const char* opt_val;
  cmdline_arg_flags_t flags;
  cmdline_usage_group_t usage_group;
} cmdline_arg_t;


// Pointer to application-specific command-line parsing function
typedef bool (*cmdline_parse_appspec_fptr_t)(cmdline_arg_t* arg,
  char* appspec_err_text_buf);


// Prototypes
int cmdline_init(int arg_count, cmdline_arg_t args[], const int argc,
  const char* argv[], cmdline_parse_appspec_fptr_t parse_appspec_fptr);
int cmdline_parse(int arg_count, cmdline_arg_t args[], int argc,
  const char* argv[], char* err_text_buf,
  cmdline_parse_appspec_fptr_t parse_appspec_fptr);
const char* cmdline_get_error_text(cmdline_error_t error);

#endif
