/*
Copyright (C) 2024 Christoph Boelitz

E-mail: tools@dosforum.de
Project page: http://tools.dosforum.de/

This program is free software as long as its used privately.
Commercial use, as unlikely as it may seem, is hereby prohibited.
The source code may be modified and distributed as long
as my contact information is left in place.

Let me know, if you have suggestions or see something that can
be done in a better way, so I might learn from it. Thanks!
*/

#ifndef _ERRMACRO_H_INCLUDED
#define _ERRMACRO_H_INCLUDED

// These macros can be used to generate an enum and corresponding array of
// error messages (both in sync) while being able to specify both elements
// in the same place. See example below.


#define GENERATE_ENUM_MEMBER(NAME, TEXT) NAME,
#define GENERATE_STRUCT_MEMBER(NAME, TEXT) { NAME, TEXT },
#define GENERATE_TEXT_MEMBER(NAME, TEXT) TEXT,


/* Example:

// Header file:
#define FOREACH_ERROR(E) \
E(E_SUCCESS, "Error handler called on non-error.") \
E(E_TIMEOUT, "There was a timeout") \
// Unknown error should always be last!
E(E_UNKNOWN, "Unknown error occured.")

typedef enum _some_error { FOREACH_ERROR(GENERATE_ENUM_MEMBER) } some_error_t;

// C file:
struct { int code; char* text; } _some_error_texts[] =
  { FOREACH_ERROR(GENERATE_STRUCT_MEMBER) };

char* get_error_text(some_error_t error)
{
  char unknown_error_text[_SOME_ERR_MSG_BUFFER_LEN];
  int i;

  for (i=0; i <= (int)E_UNKNOWN; i++)
    if (_some_error_texts[i].code == (int)error)
      return _some_error_texts[i].text;

  // Should not happen, but ok...
  return "MYERROR.C: No error description found.";
}

*/
#endif
